@@ -1,21 +1,18 @@
-# -*- coding: utf-8 -*-
 from decimal import Decimal
 
 from django import template
 from django.template import TemplateSyntaxError
 
-from moneyed import Money
-
-from ..models.fields import MoneyPatched
+from ..money import Money
+from ..utils import MONEY_CLASSES
 
 
 register = template.Library()
 
 
 class MoneyLocalizeNode(template.Node):
-
     def __repr__(self):
-        return '<MoneyLocalizeNode %d %s>' % (self.money.amount, self.money.currency)
+        return "<MoneyLocalizeNode %d %s>" % (self.money.amount, self.money.currency)
 
     def __init__(self, money=None, amount=None, currency=None, use_l10n=None, var_name=None):
         if money and (amount or currency):
@@ -38,29 +35,31 @@ class MoneyLocalizeNode(template.Node):
 
         # GET variable var_name
         if len(tokens) > 3:
-            if tokens[-2] == 'as':
+            if tokens[-2] == "as":
                 var_name = parser.compile_filter(tokens[-1])
                 # remove the already used data
                 tokens = tokens[0:-2]
 
         # GET variable use_l10n
-        if tokens[-1].lower() in ('on', 'off'):
-            use_l10n = tokens[-1].lower() == 'on'
+        if tokens[-1].lower() in ("on", "off"):
+            use_l10n = tokens[-1].lower() == "on"
             # remove the already used data
             tokens.pop(-1)
 
         # GET variable money
         if len(tokens) == 2:
-            return cls(money=parser.compile_filter(tokens[1]),
-                       var_name=var_name, use_l10n=use_l10n)
+            return cls(money=parser.compile_filter(tokens[1]), var_name=var_name, use_l10n=use_l10n)
 
         # GET variable amount and currency
         if len(tokens) == 3:
-            return cls(amount=parser.compile_filter(tokens[1]),
-                       currency=parser.compile_filter(tokens[2]),
-                       var_name=var_name, use_l10n=use_l10n)
+            return cls(
+                amount=parser.compile_filter(tokens[1]),
+                currency=parser.compile_filter(tokens[2]),
+                var_name=var_name,
+                use_l10n=use_l10n,
+            )
 
-        raise TemplateSyntaxError('Wrong number of input data to the tag.')
+        raise TemplateSyntaxError("Wrong number of input data to the tag.")
 
     def render(self, context):
 
@@ -69,24 +68,22 @@ class MoneyLocalizeNode(template.Node):
         currency = self.currency.resolve(context) if self.currency else None
 
         if money is not None:
-            if isinstance(money, Money):
-                money = MoneyPatched._patch_to_current_class(money)
-            else:
+            if not isinstance(money, MONEY_CLASSES):
                 raise TemplateSyntaxError('The variable "money" must be an instance of Money.')
 
         elif amount is not None and currency is not None:
-            money = MoneyPatched(Decimal(str(amount)), str(currency))
+            money = Money(Decimal(str(amount)), str(currency))
         else:
-            raise TemplateSyntaxError('You must define both variables: amount and currency.')
+            raise TemplateSyntaxError("You must define both variables: amount and currency.")
 
         money.use_l10n = self.use_l10n
 
         if self.var_name is None:
-            return money
+            return str(money)
 
         # as <var_name>
         context[self.var_name.token] = money
-        return ''
+        return ""
 
 
 @register.tag
@@ -111,7 +108,7 @@ def money_localize(parser, token):
 
     Return::
 
-        MoneyPatched object
+        Money object
 
     """
     return MoneyLocalizeNode.handle_token(parser, token)
